@@ -16,6 +16,7 @@ module Text.HTML.SanitizeXSS
 
     -- * Utilities
     , sanitizeAttribute
+    , sanitaryURI
     ) where
 
 import Text.HTML.SanitizeXSS.Css
@@ -151,9 +152,9 @@ acceptable_elements = ["a", "abbr", "acronym", "address", "area",
     "canvas", "caption", "center", "cite", "code", "col", "colgroup",
     "command", "datagrid", "datalist", "dd", "del", "details", "dfn",
     "dialog", "dir", "div", "dl", "dt", "em", "event-source", "fieldset",
-    "figure", "footer", "font", "form", "header", "h1", "h2", "h3", "h4",
-    "h5", "h6", "hr", "i", "img", "input", "ins", "keygen", "kbd",
-    "label", "legend", "li", "m", "map", "menu", "meter", "multicol",
+    "figcaption", "figure", "footer", "font", "form", "header", "h1", "h2",
+    "h3", "h4", "h5", "h6", "hr", "i", "img", "input", "ins", "keygen",
+    "kbd", "label", "legend", "li", "m", "main", "map", "menu", "meter", "multicol",
     "nav", "nextid", "ol", "output", "optgroup", "option", "p", "pre",
     "progress", "q", "s", "samp", "section", "select", "small", "sound",
     "source", "spacer", "span", "strike", "strong", "sub", "sup", "table",
